@@ -15,14 +15,14 @@
 #include "Zmedia.h"
 #include "Zptcl.h"
 #include "Zmass.h"
-       type(epmedia)::  mediax
-       type(ptcl)::  aPtcl  ! particle at the beggining of the segment
-       type(ptcl)::  bPtcl  ! particle at the end of the segment
+      record /epmedia/ mediax
+      record /ptcl/ aPtcl  ! particle at the beggining of the segment
+      record /ptcl/ bPtcl  ! particle at the end of the segment
       
-      massration2 = (aPtcl%mass/masel)**2
+      massration2 = (aPtcl.mass/masel)**2
       
-      gamma1 = aPtcle%fm%p(4)/aPtcl%mass
-      gamma2 = bPtcle%fm%p(4)/bPtcl%mass
+      gamma1 = aPtcle.fm.p(4)/aPtcl.mass
+      gamma2 = bPtcle.fm.p(4)/bPtcl.mass
       beta1 = sqrt(1.0 - 1./gamma1**2)
       beta2 = sqrt(1.0 - 1./gamma2**2)
       gbetasq = gamm1*beta1 * gam
