@@ -16,7 +16,8 @@
       real(8):: temp, temp2
 
       call epDraw_octagn0(comp, p, n)
-      if( comp.struc == 'octagon') then
+      if( comp.struc == 'octagon' .or. 
+     *    comp.struc == 'octagon_w' ) then
       else
 !      elseif(comp.struc == 'octagon_x') then
          do i = 1, n
