@@ -16,7 +16,8 @@
       real(8):: temp, temp2
 
       call epDraw_sqTccl0(comp, p, n)
-      if( comp.struc == 'sqTccl') then
+      if( comp.struc == 'sqTccl' .or.
+     *    comp.struc == 'sqTccl_w') then
       else
          do i = 1, n
             if( p(i).x /= gpsep ) then
