@@ -1,25 +1,25 @@
-!     **********************************
+c     **********************************
       function epPrgene(media, Eg, x) result(ans)
       use BPLPM
       implicit none
-!
-!     Generic pair creation function for entire energy region.
-!     The same note as for epPrgenex
-!
-!     Eg < PairNonSc ==> Original B.H is modified
-!     Eg < PairScrE  ==> partial screening only 
-!     PairWcrE< Ee < PairEgmaxL===>complete sc. 
-!     Ee < Eg2H      ===> complete sc.+ LPM  table
-!     Ee > Ee2H      ===> comp. + LPM  by rejection
-!
-!
+c
+c     Generic pair creation function for entire energy region.
+c     The same note as for epPrgenex
+c
+c     Eg < PairNonSc ==> Original B.H is modified
+c     Eg < PairScrE  ==> partial screening only 
+c     PairWcrE< Ee < PairEgmaxL===>complete sc. 
+c     Ee < Eg2H      ===> complete sc.+ LPM  table
+c     Ee > Ee2H      ===> comp. + LPM  by rejection
+c
+c
 #include "Zglobalc.h"
 #include "ZbasicCnst.h"
 #include "Zmedia.h"
 #include "Zmass.h"
 #include "ZepTrackp.h"
 
-       type(epmedia)::  media  ! input media
+      record /epmedia/ media  ! input media
       real(8),intent(in)::  Eg  !  photon energy in GeV.
       real(8),intent(in)::   x  !  x = Ee/Eg. (Ee one of pair
                                 ! electron  energy)
@@ -29,42 +29,40 @@
       real*8  epPairS
       real*8  epCompScrPrs
       real(8):: Egme
-!
+c
       integer i
       real*8 f, normf
-!////////////////////
-!      write(0,*) 'in epPrgene LPMeffct=',LPMeffect 
-!////////////////
+
       Egme = Eg/masele
-      if(Eg .lt. media%cnst%PairEgmin) then
+      if(Eg .lt. media.cnst.PairEgmin) then
          ans  = 0.
-      elseif(Eg .le.  media%cnst%PrScrE) then
-!       A)   normally  next one holds
-!               ------|-----------|---------
-!                     PrScrE     PairEgmaxL  
-!                    =CompScr
-!
-!       B)   next situation may not happen
-!               ------|----------|-------
-!                    PrScrE     CompScrE
-!                 =PairEgmaxL
-!           partial screening or no screening
+      elseif(Eg .le.  media.cnst.PrScrE) then
+c       A)   normally  next one holds
+c               ------|-----------|---------
+c                     PrScrE     PairEgmaxL  
+c                    =CompScr
+c
+c       B)   next situation may not happen
+c               ------|----------|-------
+c                    PrScrE     CompScrE
+c                 =PairEgmaxL
+c           partial screening or no screening
          ans = epPairS(media, Egme, x)
-      elseif(Eg .le. media%cnst%PairEgmaxL .and.
-     *       Eg .gt.   media%cnst%CompScrE) then
-!          In the case of B, this dose not happen
-!          complete screening without LPM
+      elseif(Eg .le. media.cnst.PairEgmaxL .and.
+     *       Eg .gt.   media.cnst.CompScrE) then
+c          In the case of B, this dose not happen
+c          complete screening without LPM
          ans = epCompScrPrs(media,  x)
       elseif( .not. LPMeffect ) then
          ans = epCompScrPrs(media,  x)
       else
-!          complete screening +  LPM
+c          complete screening +  LPM
          call  epNormLPMp(media,  normf)
          ans = epPairSH(media, Eg, x)*normf
       endif
 
       end
-!     ************************************
+c     ************************************
       subroutine epPrgeneTX(xmin, xmax, tx)
       implicit none
 #include "Zglobalc.h"
@@ -91,16 +89,16 @@
       tx = ans1+ans2
 
       end
-!     **************
+c     **************
       real*8 function epPrgeneSolv(v)
-!     **************
+c     **************
       implicit none
 
-!          used to solve total-cross-section * u = integral of
-!          pair function from min to v.
-!
-!
-!
+c          used to solve total-cross-section * u = integral of
+c          pair function from min to v.
+c
+c
+c
       common/upsic/upsi,vmax
       real*8 upsi, vmax
 
