@@ -1,4 +1,4 @@
-!             Basic constant
+c             Basic constant
           real*8 N0  !  Avogadro number
           real*8 r0  !  classical elecron radius. m
           real*8 alpha  ! fine structure const.
