@@ -12,15 +12,16 @@ c    This is updated in v.8.80
 c     
 c
 c
-      subroutine epStern(w0in, media)
+c      subroutine epStern(w0in, media)
+      subroutine epStern( media)
       implicit none
 #include "Zmedia.h"
 #include "Zcode.h"
 #include "Zptcl.h"
 #include "Zmass.h"
 
-      real*8  w0in  !  input. kinetic energy of knock-on electrons > w0in
-                    !         is not taken into account as energy loss( GeV).
+c      real*8  w0in  !  input. kinetic energy of knock-on electrons >c w0in
+c                    !         is not taken into account as energy locss( GeV).
 
       record  /epmedia/media  ! input. 
 c                             media.I, media.Z,media.A,
@@ -123,10 +124,13 @@ c          exceptions
 c      media.sh.xa=cb/4.60517          !  2ln(10)
 c      sh.sa = (cb-4.60517X0)/((x1-X0)**k
       sh.sa=(cb-4.60517*sh.x0)/(sh.x1-sh.x0)**sh.k
+!!
 c       some additional const relating to restriced energy loss
-      media.sh.tcut = w0in        ! in GeV 
-      media.sh.w0 = w0in * 1000.  ! in MeV unit. 
-      media.sh.wlg0 = log(media.sh.w0) 
+
+!!         to be set in  epLightNewComp-->epSetEmin.f (v9.154)
+!!      media.sh.tcut = w0in        ! in GeV 
+!!      media.sh.w0 = w0in * 1000.  ! in MeV unit. 
+!!      media.sh.wlg0 = log(media.sh.w0)  !! not used at all
 
 
       if( media.format .eq. 2) then
@@ -158,6 +162,10 @@ c         In that case, w0in must be as large as
 c         incident particle energy.
       call cmkptc(kelec, regptcl, -1, electron)
       electron.fm.p(4)= 3.162 * masele  
+!!!!!!!!!
+      media.sh.tcut = 1.0d10
+      media.sh.w0 = 1.0d10
+!!!!!!!!!!
       call epdedxe(media, electron, media.dEdxatp3m, dedxfull)
       end
 c         ***************************
