@@ -235,7 +235,7 @@
 !         called only if quenching terms are given in media data
 !        or modifier is specified 
       subroutine epOrgCorrec(modi, media, aPtcl, dedx, cf)
-#if defined (Solaris)
+#if defined (Solaris) || (jaxa) || (jaxaflat)
       use epModify,idmodiy=>id
 #else 
       use epModify
@@ -273,7 +273,7 @@
       endif
       end
       subroutine epQuenchCoeff(modi, media, aPtcl, dedx, a,b,c,id)
-#if defined (Solaris)
+#if defined (Solaris) || (jaxa) || (jaxaflat)  
       use epModify,idmodiy=>id
 #else 
       use epModify
