@@ -31,7 +31,7 @@ c/////////////
          ! count up p.e #
          if( .not. allocated( sensor( cLcompNo )%pe ) ) then
             allocate(  sensor( cLcompNo )%pe(1:5) ) 
-            allocate(  sensor( cLcompNo )%pet ) 
+!!            allocate(  sensor( cLcompNo )%pet ) 
             sensor(cLcompNo)%pe(:) = 0.
          endif
          id = cTrack.p.subcode
