@@ -5,6 +5,7 @@
 !    the axis, there appears some assymetry.  (order of 0.1 mm for few cm
 !    scale figures).
 !     
+#include "Zcondc.h"
       module sqTccl
 !           to be stored as vol attrib.
       real(8),save:: a, b, h, r
@@ -22,7 +23,11 @@
       real(8),parameter::eps= 1.d-8
       real(8),parameter::eps2= 1.d-5
       integer,save:: xconst, yconst
+#if defined (MATHLOUSY)
+      real(8),parameter:: hpi = 1.57079632679489661923d0
+#else
       real(8),parameter:: hpi = asin(1.0d0)
+#endif
       real(8),parameter:: pi =  hpi*2
       real(8),parameter:: twopi =  pi*2
       real(8),parameter:: Torad =  pi/180.d0
@@ -1009,7 +1014,8 @@ c           check
 
       record /Component/ comp  ! input.   component.
 
-      if(comp.cn /= Compnum ) then
+c      if(comp.cn /= Compnum ) then  !  honeycomb
+      if(comp.vol /= Compnum ) then
          a = Volat( comp.vol + 1)
          b = Volat( comp.vol + 2)
          h = Volat( comp.vol + 3) 
@@ -1035,7 +1041,8 @@ c           check
 !         endif
          Nfai1 = Npolygon/4*a/(a+b) + 0.5d0
          Nfai2 = Npolygon/4- Nfai1
-         Compnum = comp.cn
+!         Compnum = comp.cn
+         Compnum = comp.vol
       endif
       end  subroutine ep_sqTcclCnst
 
