@@ -289,7 +289,8 @@ c          truncation length shorter
        if( EminH == 0. ) then  ! for neutron
           EminH = 20.d-3
        else
-          EminH = min( EminH, 20.d-3)  
+!             use EminH as it is.  Mar. 18, 2014 
+!          EminH = min( EminH, 20.d-3)  
        endif
        if( RecoilKEmin .eq. 0.) then
           RecoilKEmin =EminElec - masele
