@@ -38,7 +38,6 @@ c
       end
       subroutine epsInside(pos, nci,  nco)
       implicit none
-#include  "ZepMaxdef.h"
 #include  "ZepPos.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
@@ -75,7 +74,6 @@ c))))))))))
 
       subroutine epsOne(ncx, pos, icon)
       implicit none
-#include  "ZepMaxdef.h"
 #include  "ZepPos.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
@@ -91,27 +89,31 @@ c
       record /epPos/ pos
       
       character*80 msg
-      character*8  epparaphrase, tempph
+      character(len=MAX_STRUCCHR)::  epparaphrase, tempph
 
       integer  ncx,  i, icon
       integer uscl
 c     
       i = ncx
 
-      if(Det.cmp(i).struc(1:3) .eq. 'box') then
+      if(Det.cmp(i).struc  .eq. 'box' .or.
+     *   Det.cmp(i).struc(1:4)  .eq. 'box_' ) then
          call epssbox(i, pos, icon)
 
-      elseif(Det.cmp(i).struc(1:3) .eq. 'cyl') then
+      elseif(Det.cmp(i).struc .eq. 'cyl' .or.
+     *       Det.cmp(i).struc(1:4) .eq. 'cyl_') then
          call epscyl1(i, pos, icon)
 
-      elseif(Det.cmp(i).struc(1:4) .eq. 'pipe') then
+      elseif(Det.cmp(i).struc .eq. 'pipe' .or.
+     *       Det.cmp(i).struc(1:5) .eq. 'pipe_' ) then
          call epspip1(i, pos, icon)
 
-      elseif(Det.cmp(i).struc(1:6) .eq. 'sphere') then
+      elseif(Det.cmp(i).struc .eq. 'sphere' .or.
+     *       Det.cmp(i).struc(1:7) .eq. 'sphere_' ) then
          call epsssph(i, pos, icon)
 
       elseif(Det.cmp(i).struc .eq. 'prism' .or.
-     *      Det.cmp(i).struc(1:6) .eq. 'prism_') then   
+     *      Det.cmp(i).struc(1:6) .eq. 'prism_' ) then   
          call epsprism(i, pos, icon)
       elseif(Det.cmp(i).struc(1:4) .eq. 'new-') then
          call epsNew(Det.cmp(i), pos, icon)
@@ -129,7 +131,6 @@ c
       end
       subroutine epsPCont(ncx, pos, icon)
       implicit none
-#include  "ZepMaxdef.h"
 #include  "ZepPos.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
@@ -144,7 +145,7 @@ c
       integer  ncx,  icon
 
       character*80 msg
-      character*8  epparaphrase, tempph
+      character(len=MAX_STRUCCHR)::  epparaphrase, tempph
 
       integer i, j, ii
 
@@ -155,7 +156,7 @@ c           If the point is not in any of such a parent
 c           matreska, icon = 1 will result
 c           so the point is considered not included in
 c           the current component.
-
+      character(len=MAX_STRUCCHR):: basename
 
       i = ncx
       if(Det.cmp(i).NPContainer .gt. 0) then
@@ -168,16 +169,17 @@ c            ii = Det.cmp(i).PContained(j)
             ii = CnArea( Det.cmp(i).PContained+j )
 c))))))))))
             call epw2l(ii, posw,  posl)
-            if(Det.cmp(ii).struc(1:3) .eq. 'box') then
+            call epGetBaseStrucName(Det.cmp(ii).struc, basename)
+
+            if(basename == 'box') then
                call epssbox(ii, posl, icon)
-            elseif(Det.cmp(ii).struc(1:3) .eq. 'cyl') then
+            elseif(basename == 'cyl') then
                call epscyl1(ii, posl, icon)
-            elseif(Det.cmp(ii).struc(1:4) .eq. 'pipe') then
+            elseif(basename == 'pipe') then
                call epspip1(ii, posl, icon)
-            elseif(Det.cmp(ii).struc(1:6) .eq. 'sphere') then
+            elseif( basename == 'sphere') then
                call epsssph(ii, posl, icon)
-            elseif(Det.cmp(ii).struc .eq. 'prism' .or.
-     *             Det.cmp(ii).struc(1:6) .eq. 'prism_') then
+            elseif( basename == 'prism' ) then
                call epsprism(ii, posl,  icon)
             elseif(Det.cmp(ii).struc(1:4) .eq. 'new-') then
                call epsNew(Det.cmp(ii),  posl, icon)
@@ -202,7 +204,6 @@ c))))))))))
 c             
       subroutine  epsMatreska(ncx, pos, nc)
       implicit none
-#include  "ZepMaxdef.h"
 #include  "ZepPos.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
@@ -244,7 +245,6 @@ c                 nco-th comp. contains pos, see if more matreska
 c          ncx=0--> pos is in w.c
 c         else      in l.c of ncx.
       implicit none
-#include  "ZepMaxdef.h"
 #include  "ZepPos.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
@@ -604,7 +604,6 @@ c       ************
 c              search upward  when form=box
 c       xx, yy, zz is assumed to be in ncx-local
 c
-#include  "ZepMaxdef.h"
 #include  "ZepPos.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
@@ -1176,10 +1175,10 @@ c          and momentum
       record /epPos/ posv ! input
       record /epPos/ posc ! output. 
       record /Component/ comp
-      if( comp.struc == "cyl_x") then
+      if( comp.struc(1:5) == "cyl_x") then
 c         posc = epPos( posv.z, posv.y, posv.x)
          posc = epPos( posv.y, posv.z, posv.x)
-      elseif(comp.struc == "cyl_y") then
+      elseif(comp.struc(1:5) == "cyl_y") then
 c         posc = epPos( posv.x, posv.z, posv.y)
          posc = epPos( posv.z, posv.x, posv.y)
       else
@@ -1194,10 +1193,10 @@ c         posc = epPos( posv.x, posv.z, posv.y)
       record /epPos/ posc ! input
       record /epPos/ posv ! output. 
       record /Component/ comp
-      if( comp.struc == "cyl_x") then
+      if( comp.struc(1:5) == "cyl_x") then
 c         posv = epPos( posc.z, posc.y, posc.x)
          posv = epPos( posc.z, posc.x, posc.y)
-      elseif(comp.struc == "cyl_y") then
+      elseif(comp.struc(1:5) == "cyl_y") then
 c         posv = epPos( posc.x, posc.z, posc.y)
          posv = epPos( posc.y, posc.z, posc.x)
       else
@@ -1212,10 +1211,10 @@ c         posv = epPos( posc.x, posc.z, posc.y)
       record /epPos/ dirv ! input
       record /epPos/ dirc ! output. 
       record /Component/ comp
-      if( comp.struc == "cyl_x") then
+      if( comp.struc(1:5) == "cyl_x") then
 c         dirc = epPos( dirv.z, dirv.y, dirv.x)
          dirc = epPos( dirv.y, dirv.z, dirv.x)
-      elseif(comp.struc == "cyl_y") then
+      elseif(comp.struc(1:5) == "cyl_y") then
 c         dirc = epPos( dirv.x, dirv.z, dirv.y)
          dirc = epPos( dirv.z, dirv.x, dirv.y)
       else
@@ -1230,10 +1229,10 @@ c         dirc = epPos( dirv.x, dirv.z, dirv.y)
       record /epPos/ dirc ! input
       record /epPos/ dirv ! output. 
       record /Component/ comp
-      if( comp.struc == "cyl_x") then
+      if( comp.struc(1:5) == "cyl_x") then
 c         dirv = epPos( dirc.z, dirc.y, dirc.x)
          dirv = epPos( dirc.z, dirc.x, dirc.y)
-      elseif(comp.struc == "cyl_y") then
+      elseif(comp.struc(1:5) == "cyl_y") then
 c         dirv = epPos( dirc.x, dirc.z, dirc.y)
          dirv = epPos( dirc.y, dirc.z, dirc.x)
       else
@@ -1317,3 +1316,17 @@ c         dirv = epPos( dirc.x, dirc.z, dirc.y)
          dirv = dirc
       endif
       end
+      subroutine epGetBaseStrucName(struc, mname)
+      implicit none
+      character(*),intent(in)::struc  ! box, box_w cyl cyl_y_w etc
+      character(*),intent(out):: mname  ! box cyl etc without _
+!            normally   their length = MAX_STRUCCHR but could be less or more
+!        
+      integer:: i
+      i = index(struc, '_')
+      if( i > 0 ) then
+         mname=struc(1:i-1)
+      else
+         mname= struc
+      endif
+      end   subroutine epGetBaseStrucName
